==> MouseAgingData_0.99.1.tar.gz: MouseAgingData/inst/doc/MouseAgingData_parabiosis_droplet.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL
)

## ----eval = FALSE-------------------------------------------------------------
#  # if(!requireNamespace("BiocManager", quietly = TRUE))
#      # install.packages("BiocManager")
#  # BiocManager::install("MouseAgingData")

## ----message = FALSE----------------------------------------------------------
library(scran)
library(scater)
library(ggplot2)
library(bluster)
library(SingleCellExperiment)
library(ExperimentHub)
library(MouseAgingData)

## -----------------------------------------------------------------------------
sce <- parabiosis10X()
sce

## ----Data check---------------------------------------------------------------
# Check sce dimensions
dim(sce)

# Sample metadata
head(colData(sce)) 

# Includes cell colors from the original paper
metadata(sce)

# The count matrix. Transcript for each gene per cell (column)
head(counts(sce)) 

## -----------------------------------------------------------------------------
sce_subset <- sce[, 1:1000]

## ----normalize----------------------------------------------------------------
set.seed(101000110)
clusters <- quickCluster(sce_subset)
sce_subset <- computeSumFactors(sce_subset, clusters=clusters)
sce_subset <- logNormCounts(sce_subset)

head(logcounts(sce_subset))

## ----feat select--------------------------------------------------------------
dec <- modelGeneVar(sce_subset)
hvg <- getTopHVGs(dec, prop=0.1)

## ----PCA, warning=FALSE, eval=FALSE-------------------------------------------
#  set.seed(1234)
#  sce_subset <- runPCA(sce_subset, ncomponents=25, subset_row=hvg)
#  # Add PCA coords to sce object

## ----viewPCA, warning=FALSE---------------------------------------------------
head(reducedDim(sce_subset, "PCA"))[1:5, 1:5]

## ----clustering---------------------------------------------------------------
colLabels(sce_subset) <- clusterCells(sce_subset, use.dimred='PCA',
                               BLUSPARAM=NNGraphParam(cluster.fun="louvain"))

## ----provided umap, fig.height = 4, fig.width = 6.5---------------------------
# Generate color map matching cell type to colors in publication
cell.color <- metadata(sce_subset)$cell_color

gg <- plotUMAP(sce_subset, color_by = "cell_type", text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----plot provided TSNE, fig.height = 4, fig.width = 6.5----------------------
gg <- plotTSNE(sce, color_by = "cell_type", text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----UMAP2, fig.height = 4, fig.width = 6.5-----------------------------------
# Add our UMAP to the reducedDims slot with the name "osca_UMAP" so we do not
# confused it with the author's UMAP coords.
sce <- runUMAP(sce, dimred = 'PCA', name = "osca_UMAP")

# When we want to access a specific item (here, "osca_UMAP") in the reducedDims
# element of the SingleCellExperiment object, we can use the function
# plotReducedDim with the argument dimred.

gg <- plotReducedDim(sce, dimred = "osca_UMAP", color_by = "cell_type", 
                     text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----TSNE2, fig.height = 4, fig.width = 6.5-----------------------------------
# Run TSNE
set.seed(00101001101)

# runTSNE() stores the t-SNE coordinates in the reducedDims
sce <- runTSNE(sce, dimred = 'PCA', name = "osca_TSNE")

gg <- scater::plotReducedDim(sce, dimred = "osca_TSNE", color_by = "cell_type", 
                     text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----sesh info----------------------------------------------------------------
sessionInfo()

==> MouseAgingData_0.99.6.tar.gz: MouseAgingData/inst/doc/MouseAgingData_parabiosis_droplet.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL
)

## ----eval = FALSE-------------------------------------------------------------
#  # if(!requireNamespace("BiocManager", quietly = TRUE))
#      # install.packages("BiocManager")
#  # BiocManager::install("MouseAgingData")

## ----message = FALSE----------------------------------------------------------
library(scran)
library(scater)
library(ggplot2)
library(bluster)
library(SingleCellExperiment)
library(ExperimentHub)
library(MouseAgingData)

## -----------------------------------------------------------------------------
sce <- parabiosis10X()

## -----------------------------------------------------------------------------
# View the data
sce

## ----Data check---------------------------------------------------------------
# Sample metadata
head(colData(sce)) 

## -----------------------------------------------------------------------------
# Includes cell colors from the original paper
metadata(sce)

## ----subset sce---------------------------------------------------------------
sce_subset <- sce[, 1:1000]

## ----normalize----------------------------------------------------------------
set.seed(101000110)
clusters <- quickCluster(sce_subset)
sce_subset <- computeSumFactors(sce_subset, clusters=clusters)
sce_subset <- logNormCounts(sce_subset)

logcounts(sce_subset)[1:10, 1:10]

## ----feat select--------------------------------------------------------------
dec <- modelGeneVar(sce_subset)
hvg <- getTopHVGs(dec, prop=0.1)

## -----------------------------------------------------------------------------
head(rowData(sce))

## ----PCA, warning=FALSE-------------------------------------------------------
# Since we already have PCA coords from our authors, we will add these computed 
# PCA coords under a different name "osca_PCA"

set.seed(1234)
sce_subset <- runPCA(sce_subset, ncomponents=25, subset_row=hvg, 
                     name = "osca_PCA")


# Show the names of the elements in the ReducedDims slot
reducedDims(sce_subset)

## ----viewPCA, warning=FALSE---------------------------------------------------
reducedDim(sce_subset, "PCA")[1:5, 1:5]

## ----clustering---------------------------------------------------------------
colLabels(sce_subset) <- clusterCells(sce_subset, use.dimred='osca_PCA',
                               BLUSPARAM=NNGraphParam(cluster.fun="louvain"))

## ----fig.height = 4, fig.width = 6.5------------------------------------------

# Generate color map matching cell type to colors in publication
cell.color <- metadata(sce)$cell_color

gg <- plotUMAP(sce, color_by = "cell_type", text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----plot provided tSNE, fig.height = 4, fig.width = 6.5----------------------
gg <- plotTSNE(sce, color_by = "cell_type", text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----sesh info----------------------------------------------------------------
sessionInfo()
